//------------------------------------------------------------------------------
//------------------------------------------------------------------------------
// Event Types - Made by Blnukem
//------------------------------------------------------------------------------
// Affliction Events:
//------------------------------------------------------------------------------

function Nothing() { // Lets have nothing happen here.
   Warn("Random Event: No significant events have occured.");
   return;
}

function AfflictionDemonSpawns() { // Trying another approach, lets not use Zombie points.
   Warn("Random Event: A demon assault group has spawned.");
   Schedule(5000, 0, "MessageAll", "", "\c2CENTRAL COMMAND :: \c0They are in the perimeter of the Caldera Outpost. ~wvoice/Training/Mission4/T4.warning01.wav");
   %cycle = getRandom(1, 3); // Lets randomize this a little.
   if(%cycle == 2) {
      StartAZombie("303.442 -944.818 50", 4);
      StartAZombie("323.842 -917.359 50", 4);
      StartAZombie("109.885 -609.351 50", 4);
      StartAZombie("203.516 -632.557 71.5642", 4);
      StartAZombie("-150.563 -1088.23 50", 4);
   } else if(%cycle == 3) {
      StartAZombie("85.2387 -1190.61 50", 4);
      StartAZombie("137.615 -1066.1 50", 4);
      StartAZombie("217.756 -981.153 50", 4);
      StartAZombie("-80.6047 -733.875 53.0005", 4);
      StartAZombie("-137.281 -925.065 54.9172", 4);
   } else {
      StartAZombie("-4.88373 -1173.03 50", 4);
      StartAZombie("277.311 -875.861 50", 4);
      StartAZombie("119.194 -644.181 50", 4);
      StartAZombie("85.2387 -1190.61 50", 4);
      StartAZombie("-150.563 -1088.23 50", 4);
   return;
   }
}

function AfflictionDemonMotherSpawn() { // Ya better hope this event doesn't happen.
   Warn("Random Event: A demon mother has spawned.");
   %cycle = getRandom(1, 3); // The demon mother will spawn at 1 of 3 locations.
   if(%cycle == 2) {
   DemonMotherCreate("-390.611 -1205.91 213.949");
   } else if(%cycle == 3) {
   DemonMotherCreate("506.993 -695.833 79.9792");
   } else {
   DemonMotherCreate("334.069 -1140.46 244.424");
   return;
   }
}

function AfflictionMediumAttack() {
   Warn("Random Event: A moderate Zombie attack has occured.");
   Call("EnableSpawn", "EventSpawn01");
   Call("EnableSpawn", "EventSpawn02");
   Call("EnableSpawn", "EventSpawn06");
   Call("EnableSpawn", "EventSpawn08");
   Call("EnableSpawn", "EventSpawn09");
   Call("EnableSpawn", "EventSpawn10");
   Call("EnableSpawn", "EventSpawn11");
   Call("EnableSpawn", "EventSpawn12");
   Schedule(5000, 0, "MessageAll", "", "\c2CENTRAL COMMAND :: \c0They are in the perimeter of the Caldera Outpost. ~wvoice/Training/Mission4/T4.warning01.wav");
   return;
}

function AfflictionHeavyAttack() {
   Warn("Random Event: A heavy Zombie attack has occured.");
   Call("EnableSpawn", "EventSpawn01");
   Call("EnableSpawn", "EventSpawn02");
   Call("EnableSpawn", "EventSpawn03");
   Call("EnableSpawn", "EventSpawn04");
   Call("EnableSpawn", "EventSpawn05");
   Call("EnableSpawn", "EventSpawn06");
   Call("EnableSpawn", "EventSpawn07");
   Call("EnableSpawn", "EventSpawn08");
   Call("EnableSpawn", "EventSpawn09");
   Call("EnableSpawn", "EventSpawn10");
   Call("EnableSpawn", "EventSpawn11");
   Call("EnableSpawn", "EventSpawn12");
   Call("EnableSpawn", "EventSpawn13");
   Schedule(5000, 0, "MessageAll", "", "\c2CENTRAL COMMAND :: \c0They are in the perimeter of the Caldera Outpost. ~wvoice/Training/Mission4/T4.warning01.wav");
   return;
}

function AfflictionRapierAttack() {
   Warn("Random Event: A Rapier Zombie attack has occured.");
   Call("EnableSpawn", "EventRSpawn01");
   Call("EnableSpawn", "EventRSpawn02");
   Schedule(5000, 0, "MessageAll", "", "\c2CENTRAL COMMAND :: \c0They are in the perimeter of the Caldera Outpost. ~wvoice/Training/Mission4/T4.warning01.wav");
   return;
}
